@@ -1,4 +1,4 @@
-from Notion.page import Page
+from .page import Page
 
 class Pagelist:
     def __init__(self, pagelist):
